@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2013
+* (C) Francesco Mondello 2009-2014
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@ public:
 private slots:
     void openFacebookPage();
     void openGooglePlusPage();
+    void on_pushDonatePayPal_clicked();
+    void on_pushDonateFlattr_clicked();
 };
 
 #endif // DIALOGINFO_H
